@@ -14,6 +14,15 @@ class Resource(object):
     def __init__(self, obj):
         self.obj = obj
 
+    def __getstate__(self):
+        return self.obj.items()
+
+    def __setstate__(self, items):
+        if not hasattr(self, 'obj'):
+            self.obj = {}
+        for key, val in items:
+            self.obj[key] = val
+
     def __getattr__(self, name):
         if name in self.obj:
             return self.obj.get(name)
